@@ -49,12 +49,12 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
         
     """
     
-    _validate_input(input_tensors=(x, y), allow_5d=False)
+    _validate_input(input_tensors=(x, y), allow_5d=False, data_range=data_range)
     x, y = _adjust_dimensions(input_tensors=(x, y))
     
     # Rescale to [0, 255] range, because all constant are calculated for this factor
-    x = (x / float(data_range)) * 255
-    y = (y / float(data_range)) * 255
+    x = x / data_range * 255
+    y = y / data_range * 255
     
     # Apply average pooling
     kernel_size = max(1, round(min(x.shape[-2:]) / 256))
@@ -107,6 +107,7 @@ def fsim(x: torch.Tensor, y: torch.Tensor, reduction: str = 'mean',
     score = GM * PC * pc_max
     
     if chromatic:
+        assert num_channels == 3, "Chromatic component can be computed only for RGB images!"
         S_I = similarity_map(x_i, y_i, T3)
         S_Q = similarity_map(x_q, y_q, T4)
         score = score * torch.abs(S_I * S_Q) ** lmbda
