@@ -1,11 +1,11 @@
-from piq.functional.base import ifftshift, get_meshgrid, similarity_map, gradient_map, pow_for_complex
+from piq.functional.base import ifftshift, get_meshgrid, similarity_map, gradient_map, pow_for_complex, crop_patches
 from piq.functional.colour_conversion import rgb2lmn, rgb2xyz, xyz2lab, rgb2lab, rgb2yiq, rgb2lhm
 from piq.functional.filters import haar_filter, hann_filter, scharr_filter, prewitt_filter, gaussian_filter
 from piq.functional.layers import L2Pool2d
 
 
 __all__ = [
-    'ifftshift', 'get_meshgrid', 'similarity_map', 'gradient_map', 'pow_for_complex',
+    'ifftshift', 'get_meshgrid', 'similarity_map', 'gradient_map', 'pow_for_complex', 'crop_patches',
     'rgb2lmn', 'rgb2xyz', 'xyz2lab', 'rgb2lab', 'rgb2yiq', 'rgb2lhm',
     'haar_filter', 'hann_filter', 'scharr_filter', 'prewitt_filter', 'gaussian_filter',
     'L2Pool2d',
