@@ -47,11 +47,15 @@ def ssim(x: torch.Tensor, y: torch.Tensor, kernel_size: int = 11, kernel_sigma:
            https://ece.uwaterloo.ca/~z70wang/publications/ssim.pdf,
            :DOI:`10.1109/TIP.2003.819861`
     """
-    _validate_input(input_tensors=(x, y), allow_5d=True, kernel_size=kernel_size, scale_weights=None)
+    _validate_input(
+        input_tensors=(x, y), allow_5d=True, kernel_size=kernel_size, scale_weights=None, data_range=data_range)
     x, y = _adjust_dimensions(input_tensors=(x, y))
-    if isinstance(x, torch.ByteTensor) or isinstance(y, torch.ByteTensor):
-        x = x.type(torch.float32)
-        y = y.type(torch.float32)
+
+    x = x.type(torch.float32)
+    y = y.type(torch.float32)
+        
+    x = x / data_range
+    y = y / data_range
 
     kernel = gaussian_filter(kernel_size, kernel_sigma).repeat(x.size(1), 1, 1, 1).to(y)
     _compute_ssim_per_channel = _ssim_per_channel_complex if x.dim() == 5 else _ssim_per_channel
@@ -207,11 +211,17 @@ def multi_scale_ssim(x: torch.Tensor, y: torch.Tensor, kernel_size: int = 11, ke
            https://ece.uwaterloo.ca/~z70wang/publications/ssim.pdf,
            :DOI:`10.1109/TIP.2003.819861`
     """
-    _validate_input(input_tensors=(x, y), allow_5d=True, kernel_size=kernel_size, scale_weights=scale_weights)
+    _validate_input(
+        input_tensors=(x, y), allow_5d=True, kernel_size=kernel_size,
+        scale_weights=scale_weights, data_range=data_range
+    )
     x, y = _adjust_dimensions(input_tensors=(x, y))
-    if isinstance(x, torch.ByteTensor) or isinstance(y, torch.ByteTensor):
-        x = x.type(torch.float32)
-        y = y.type(torch.float32)
+
+    x = x.type(torch.float32)
+    y = y.type(torch.float32)
+
+    x = x / data_range
+    y = y / data_range
 
     if scale_weights is None:
         scale_weights_from_ms_ssim_paper = [0.0448, 0.2856, 0.3001, 0.2363, 0.1333]
@@ -369,8 +379,8 @@ def _ssim_per_channel(x: torch.Tensor, y: torch.Tensor, kernel: torch.Tensor,
         raise ValueError(f'Kernel size can\'t be greater than actual input size. Input size: {x.size()}. '
                          f'Kernel size: {kernel.size()}')
 
-    c1 = (k1 * data_range) ** 2
-    c2 = (k2 * data_range) ** 2
+    c1 = k1 ** 2
+    c2 = k2 ** 2
     n_channels = x.size(1)
     mu1 = F.conv2d(x, weight=kernel, stride=1, padding=0, groups=n_channels)
     mu2 = F.conv2d(y, weight=kernel, stride=1, padding=0, groups=n_channels)
@@ -459,8 +469,8 @@ def _ssim_per_channel_complex(x: torch.Tensor, y: torch.Tensor, kernel: torch.Te
         raise ValueError(f'Kernel size can\'t be greater than actual input size. Input size: {x.size()}. '
                          f'Kernel size: {kernel.size()}')
 
-    c1 = (k1 * data_range) ** 2
-    c2 = (k2 * data_range) ** 2
+    c1 = k1 ** 2
+    c2 = k2 ** 2
 
     x_real = x[..., 0]
     x_imag = x[..., 1]
